@@ -19,7 +19,7 @@ def impute_missing_data(df: pd.DataFrame):
 
 def make_bins(df: pd.DataFrame, equal_bins: bool, nr_bins: int):
     if equal_bins:
-        df += np.random.normal(0, 10e5, df.shape[0] * df.shape[1]).reshape(df.shape[0], df.shape[1])
+        df += np.random.normal(0, 1e-5, df.shape[0] * df.shape[1]).reshape(df.shape[0], df.shape[1])
         return df.apply(lambda x: pd.qcut(x, nr_bins, labels=False), axis=1) + 1
     else:
         return df.apply(lambda x: pd.cut(x, nr_bins, labels=False), axis=1) + 1
@@ -58,8 +58,7 @@ def compute_signal(
     equal_bins: bool=True,
     impute_missing_values: bool=True,
     output_format :str="long",
-    keep_raw_signal: bool=True) -> pd.DataFrame:
-    
+    keep_raw_signal: bool=True) -> pd.DataFrame:   
     """
     """
     signal_wide = signal_make_bins(df, nr_bins, equal_bins, impute_missing_values)
@@ -105,16 +104,18 @@ def merge_ret_signal(ret: pd.DataFrame, signal: pd.DataFrame, on: str="same_date
             .merge(signal, on=["date", "variable"], how="left")
             .sort_values(by=["date", "signal_raw"])
             .set_index("date")
+            .loc[:, ["variable", "signal_raw", "signal_bin", "ret"]]
         )
     elif on == "week_year":
-        ret["week"] = ret.date.dt.week
+        ret["week"] = ret.date.dt.isocalendar().week
         ret["year"] = ret.date.dt.year
-        signal["week"] = signal.date.dt.week
+        signal["week"] = signal.date.dt.isocalendar().week
         signal["year"] = signal.date.dt.year
         return (ret
-            .merge(signal, on=["week", "year", "variable"], how="right")
+            .merge(signal.loc[:, signal.columns != 'date'], on=["week", "year", "variable"], how="right")
             .sort_values(by=["date", "signal_raw"])
             .set_index("date")
+            .loc[:, ["variable", "signal_raw", "signal_bin", "ret"]]
         )
     elif on == "month_year":
         ret["month"] = ret.date.dt.month
@@ -122,12 +123,13 @@ def merge_ret_signal(ret: pd.DataFrame, signal: pd.DataFrame, on: str="same_date
         signal["month"] = signal.date.dt.month
         signal["year"] = signal.date.dt.year
         return (ret
-            .merge(ret, on=["month", "year", "variable"], how="right")
+            .merge(signal.loc[:, signal.columns != 'date'], on=["month", "year", "variable"], how="right")
             .sort_values(by=["date", "signal_raw"])
             .set_index("date")
+            .loc[:, ["variable", "signal_raw", "signal_bin", "ret"]]
         )
     else:
-        raise ValueError("on can only take values: date, week_year, month_year")
+        raise ValueError("on can only take values: 'same_date', 'week_year', 'month_year'")
 
     
 def compute_rolling_vol(df:pd.DataFrame, emw=True, **kwargs) -> pd.DataFrame:
@@ -392,8 +394,7 @@ def plot_performance_statistics(
 
 def compute_long_short_portfolio(df, long_bin :list, short_bin: list, weight_func, **kwargs):
     """
-    """
-    
+    """   
     df_long = df[df['signal_bin'].isin(long_bin)]
     df_short = df[df['signal_bin'].isin(short_bin)]
     # apply weighting
